==> source-highlight-1.6.2.tar.gz: source-highlight-1.6.2/src/lib/genfun.h <==
/*
 * Copyright (C) 1999, 2000, 2001  Lorenzo Bettini <bettini@gnu.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifndef _GENFUN_H
#define _GENFUN_H

#include <iostream>

using std::ostream;

extern char *inputFileName ; /* what we're reading  */
extern ostream* sout ;

char *createOutputFileName( char *inputFileName ) ;
void processFile( char *source_language, char *output_format,
                  char *inputFileName, char *outputFileName, char *docTitle,
                  const char *docHeader, const char *docFooter,
                  short entire_doc, char *cssUrl ) ;
char *getCodeLine( void ) ;
void print_cgi_header();
void print_top( char *docTitle, char *s , const char *docHeader,
                char *inputFileName) ;
void print_bottom( const char *docFooter ) ;
void print_xtop( char *docTitle, char *s , const char *docHeader,
                char *inputFileName) ;
void print_xbottom( const char *docFooter ) ;
void generate( const char *s ) ;
void generate( const char *s, int start, int end ) ;
void generateln( const char *s ) ;
void generate_preproc(const char *s);
void generate_normal(const char *s);
void generateNewLine() ;
void generateTab() ;
void generateComment( const char *s ) ;
void generateString( const char *s ) ;
void generateKeyWord( const char *s ) ;
void generatePreProc( const char *s ) ;
void generateBaseType( const char *s ) ;
void generateNumber( const char *s ) ;
void generateSymbol( const char *s ) ;
void generateFunction( const char *s ) ;
void generateCBracket( const char *s ) ;

void startComment( const char *s ) ;
void endComment( const char *s = 0 ) ; // 0 for // comments
void startString( const char *s ) ;
void endString( const char *s ) ;

void startTAG( const char *tag, const char *attr = 0, const char *val = 0 ) ;
void endTAG( const char *tag ) ;

#endif // _GENFUN_H

==> source-highlight-1.8.tar.gz: source-highlight-1.8/src/lib/genfun.h <==
/*
 * Copyright (C) 1999, 2000, 2001  Lorenzo Bettini <bettini@gnu.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifndef _GENFUN_H
#define _GENFUN_H

#include <iostream>

using std::ostream;

extern char *inputFileName ; /* what we're reading  */
extern ostream* sout ;

char *createOutputFileName( char *inputFileName ) ;
void processFile( char *source_language, char *output_format,
                  char *inputFileName, char *outputFileName,
                  short entire_doc) ;
char *getCodeLine( void ) ;
void generate( const char *s ) ;
void generate( const char *s, int start, int end ) ;
void generateln( const char *s ) ;
void generate_preproc(const char *s);
void generate_normal(const char *s);
void generateNewLine() ;
void generateTab() ;
void generateComment( const char *s ) ;
void generateString( const char *s ) ;
void generateKeyWord( const char *s ) ;
void generatePreProc( const char *s ) ;
void generateBaseType( const char *s ) ;
void generateNumber( const char *s ) ;
void generateSymbol( const char *s ) ;
void generateFunction( const char *s ) ;
void generateCBracket( const char *s ) ;

void startComment( const char *s ) ;
void endComment( const char *s = 0 ) ; // 0 for // comments
void startString( const char *s ) ;
void endString( const char *s ) ;

#endif // _GENFUN_H
